@@ -35,6 +35,7 @@ logging and a plugin framework are contained within the openlp.core module.
 
 import os
 import sys
+import platform
 import logging
 from optparse import OptionParser
 from traceback import format_exception
@@ -102,8 +103,13 @@ class OpenLP(QtGui.QApplication):
         Run the OpenLP application.
         """
         self.eventLoopIsActive = False
-        # On Windows, the args passed into the constructor are
-        # ignored. Not very handy, so set the ones we want to use.
+        # On Windows, the args passed into the constructor are ignored. Not
+        # very handy, so set the ones we want to use. On Linux and FreeBSD, in
+        # order to set the WM_CLASS property for X11, we pass "OpenLP" in as a
+        # command line argument. This interferes with files being passed in as
+        # command line arguments, so we remove it from the list.
+        if 'OpenLP' in args:
+            args.remove('OpenLP')
         self.args.extend(args)
         # provide a listener for widgets to reqest a screen update.
         QtCore.QObject.connect(Receiver.get_receiver(),
@@ -266,6 +272,9 @@ def main(args=None):
         qt_args.extend(['-style', options.style])
     # Throw the rest of the arguments at Qt, just in case.
     qt_args.extend(args)
+    # Bug #1018855: Set the WM_CLASS property in X11
+    if platform.system() not in ['Windows', 'Darwin']:
+        qt_args.append('OpenLP')
     # Initialise the resources
     qInitResources()
     # Now create and actually run the application.
