@@ -541,12 +541,13 @@ class SongImportSourcePage(QtGui.QWizardPage):
                 if wizard.formatWidgets[format][u'fileListWidget'].count() > 0:
                     return True
             else:
-                filepath = wizard.formatWidgets[format][u'filepathEdit'].text()
-                if not filepath.isEmpty():
-                    if select_mode == SongFormatSelect.SingleFile \
-                        and os.path.isfile(filepath):
+                filepath = unicode(
+                    wizard.formatWidgets[format][u'filepathEdit'].text())
+                if filepath:
+                    if select_mode == SongFormatSelect.SingleFile and \
+                        os.path.isfile(filepath):
                         return True
-                    elif select_mode == SongFormatSelect.SingleFolder \
-                        and os.path.isdir(filepath):
+                    elif select_mode == SongFormatSelect.SingleFolder and \
+                        os.path.isdir(filepath):
                         return True
         return False
